require('controls')
require('tostring') -- for printing tables
function love.load()
	controls.load()

	screenHeight = love.graphics.getHeight()
	screenWidth = love.graphics.getWidth()
	countdown = false
	countdown_start = 3.99

	--||=======EXTERNAL VALUES=======||

	hidden_timer = 0

	gravity = 1000
	game_timer = 99.99
	game_start = false
	game_end = false
	timer_end = 2
	inputThreshold = 0.25
	winner = ""


	--||=======FLOOR=======||--
	floor = {}
	floor.w = screenWidth
	floor.h = 150
	floor.x = 0
	floor.y = screenHeight - floor.h

	box = {}
	------------------------

	--[[PLAYER 1]]--
	box[1] = {} 
	box[1].w = 50
	box[1].h = 50
	box[1].x = 100
	box[1].y = screenHeight - floor.y - box[1].h
	box[1].ground_vel = 500
	box[1].ground_vel_base = box[1].ground_vel
	box[1].run_vel = 750
	box[1].jump_vel = -600
	box[1].jump_vel_base = box[1].jump_vel
	box[1].keyBuffer = ""
	box[1].facing = "right"
	box[1].jumping = true
	box[1].state = "idle"
	box[1].keylocked = true
	box[1].keyCompare = {}
	box[1].health = 100

	--[[PLAYER 2]]--
	box[2] = {}
	box[2].w = 50
	box[2].h = 50
	box[2].x = screenWidth - 100
	box[2].y = screenHeight - floor.y - box[2].h
	box[2].ground_vel = 500
	box[2].ground_vel_base = box[2].ground_vel
	box[2].run_vel = 750
	box[2].jump_vel = -600
	box[2].jump_vel_base = box[2].jump_vel
	box[2].keyBuffer = ""
	box[2].facing = "left"
	box[2].jumping = true
	box[2].state = "idle"
	box[2].keylocked = true
	box[2].keyCompare = {}
	box[2].health = 200


end

function love.update(dt)

	--Extra init for updating values

	for i = 1,2 do
		box[i].r = box[i].x + box[i].w
		box[i].b = box[i].y + box[i].h
		box[i].m = (box[i].x + box[i].r)/2
	end


	--Pregame

	hidden_timer = hidden_timer + dt

	if hidden_timer > 2 then
		countdown = true
		if countdown then
			countdown_start = countdown_start - dt
			if countdown_start < 0 then
				game_start = true
				for i = 1,2 do 
					box[i].keylocked = false
					countdown = false
				end
			end
		end
	end


	if game_start then
		game_timer = game_timer - dt
		if game_timer < 0 then
			game_timer = 0
			game_end = true
		end
	end


	--Endgame

	if game_end then
		timer_end = timer_end - dt
		if timer_end < 0 then
			timer_end = -1
			for i = 1,2 do
				box[i].keylocked = true
				if box[1].health > box[2].health then
					winner = "PLAYER 1 WINS!"
				elseif box[2].health > box[1].health then
					winner = "PLAYER 2 WINS!"
				end
			end
		end
	end

	--Inputs

	for i = 1,2 do
		if #box[i].keyCompare == 2 then
			if box[i].keyCompare[2].input_time - box[i].keyCompare[1].input_time > inputThreshold then
				box[i].keyBuffer = ""
				for _ = 1,2 do
					table.remove(box[i].keyCompare, 1)
				end
			end
		end
	end
end

function love.draw()
	love.graphics.print(hidden_timer, 100, 85)
	love.graphics.printf(math.floor(game_timer), 0, 50, screenWidth, "center")
	if game_end then
		love.graphics.print(winner, 100, 115)
	end

	if box[1].keylocked then
		love.graphics.print("keylocked: true", 100, 100)
	elseif not box[1].keylocked then
		love.graphics.print("keylocked: false", 100, 100)
	end

	if countdown then
		love.graphics.printf(math.floor(countdown_start), 0, screenHeight/2, screenWidth, "center")
	end

	love.graphics.print(timer_end, 100, 150)

	-- for j = 1,2 do
	-- 	for i,v in ipairs(box[j].keyCompare.input_time) do
	-- 		love.graphics.print(v.keyCompare.input_time, 100, 170)
	-- 	end
	-- end

	-- for i = 1,2 do
	-- 	if #box[i].keyCompare.inputTimer > 0 then
	-- 		love.graphics.print(box[i].keyCompare.inputTimer[1], 100, 170)
	-- 		if #box[i].keyCompare.inputTimer > 1 then
	-- 			love.graphics.print(box[i].keyCompare.inputTimer[2], 100, 170)
	-- 		end
	-- 	end
	-- end

	-- table.foreach(table,f)
	-- for i = 1,2 do 
	-- 	if #box[i].keyCompare.input_time > 0 then
	-- 		table.foreachi(box[i].keyCompare.input_time, print)
	-- 	end
	-- end

end

function love.keypressed(key, unicode)
	for i = 1,2 do
		if not box[i].keylocked then
			if key == pControl[i].Weak or key == pControl[i].Strong or key == pControl[i].Special or key == pControl[i].Grab 
			or key == pControl[i].Up or key == pControl[i].Down or key == pControl[i].Left or key == pControl[i].Right then	
				box[i].keyBuffer = key..box[i].keyBuffer
				table.insert(box[i].keyCompare, {input_time = hidden_timer})
				print("box[" .. i .. "].keyCompare:")
				print(to_string(box[i].keyCompare))
			end
		end
	end
end












